# Post-installation de Archlinux

Après l'installation de l'OS Archlinux nous se retrouve avec l'environnement graphique de son choix (ici Gnome) et les paquets nécéssaires pour faire tourner correctement la machine. Les bases d'Archlinux sont posées, il reste cependant à faire quelques nouvelles installations et configurations pour étoffer le système.

## Configuration dans Gnome

### Les extensions Gnome Shell
Installer l'extension _Intégration à GNOME Shell_  dans Firefox.

![Liste des extensions de Gnome](https://git.ouvaton.coop/nodiego/Arch-Linux-Cool/src/branch/master/img/%20archcool-img-03.png)

![Liste des extensions de Gnome](https://git.ouvaton.coop/nodiego/Arch-Linux-Cool/src/branch/master/img/%20archcool-img-03.png)

## Installations et configurations des logiciels

### Le Pare-feu
UFW est un bon pare-feu pour un usage domestique qui requière une sécurité de base mais robuste:

```
sudo pacman -S ufw gufw
```

Configuration de base :

```
# ufw default deny
# ufw allow from 192.168.0.0/24
# ufw allow Deluge
# ufw limit ssh
```
Pour lancer et activer le service :
```
sudo systemctl start ufw
sudo systemctl enable ufw
```

Contrôler le statut du pare-feu :
```
sudo ufw status
```
La configuration peut également se faire graphiquement avec gufw :

![GUFW](https://git.ouvaton.coop/nodiego/Arch-Linux-Cool/raw/branch/master/img/archcool-img-02.png#center "GUFW")

Réinitialiser les règles et ajouter manuellement celles de CUPS et KDE Connect.

### Firefox

Installer les extensions suivantes : *uBlock Origin, Privacy Badger, Grammalecte*

### Libre Office

Récupérer le dossier *~/.config/libreoffice* qui sauvegarde les personalisations.
Installer l'extention *Grammalecte*.

Pour préformater les pages en A4 (paquet libpaper):
```
sudo paperconfig -p a4
```
Pour donner l'apparence de MS Office, cliquer sur l'onglet "Affichage" puis "Interface utilisateur..." :


![interface utilisateur](https://git.ouvaton.coop/nodiego/Arch-Linux-Cool/raw/branch/master/img/archcool-img-01.png "Interface utilisateur...")


### Oh my zsh !

[https://ohmyz.sh](https://ohmyz.sh)
[https://github.com/ohmyzsh/ohmyzsh](https://github.com/ohmyzsh/ohmyzsh)

Tuto video : [https://www.youtube.com/watch?v=3KzIQFPWs2Y](https://www.youtube.com/watch?v=3KzIQFPWs2Y)

Installer depuis [https://ohmyz.sh/](https://ohmyz.sh/).
<br>
Pour les plugins voir [https://github.com/zsh-users](https://github.com/zsh-users) :

* [zsh-syntax-highlighting](https://github.com/zsh-users/zsh-syntax-highlighting);
* [zsh-autosuggestions](https://github.com/zsh-users/zsh-autosuggestions);
* [zsh-completions](https://github.com/zsh-users/zsh-completions).

Cloner les plugins puis les déplacer dans le dossier ~/.oh-my-zsh/plugins :

```
mv zsh* .oh-my-zsh/plugins
```

Il faut ensuite signaler les plugins dans la partie :

```
nano .zshrc
```
puis :
```
plugins=(git
zsh-syntax-highlighting
zsh-completions
zsh-autosuggestions
)
```

##### Installer un thème Zsh

Pour installer le thème "powerlevel10k", il faut cloner le git suivant : [https://github.com/romkatv/powerlevel10k.git](https://github.com/romkatv/powerlevel10k)
et le déplacer dans ~/.oh-my-zsh/themes :

```
mv powerlevel10k .oh-my-zsh/themes 
```

Éditer et relancer ~/.zshrc -> *ZSH_THEME="powerlevel10k/powerlevel10k"*

```
nano .zshrc
source .zshrc
```

Éditer et relancer ~/.p10k.zsh pour paramétrer -> tout commenter sauf :

* status, command_execution_time, background_jobs, direnv, load, disk_usage, ram, swap

```
nano .p10k.zsh
source .p10k.zsh
```

### Rhythmbox

Sauvegarder le dossier caché *~/.local/share/rhythmbox*, puis le restaurer après l'installation.

- [https://doc.ubuntu-fr.org/rhythmbox](https://doc.ubuntu-fr.org/rhythmbox)
- [https://wiki.archlinux.org/title/Rhythmbox](https://wiki.archlinux.org/title/Rhythmbox)

#### Choix des Greffons pour Rhythmbox :

- Barre d'outils alternative ([aur](https://aur.archlinux.org/packages/rhythmbox-plugin-alternative-toolbar), [git](https://github.com/fossfreedom/alternative-toolbar))
- Lecteurs portables - MTP
- Notification
- Paroles de chansons
- Recherche de pochette

### Thunderbird

Ajouter l'extension *Grammalecte*.


### yt-dlp (remplace Youtube-dl)

Petit programme en ligne de commande pour récupérer les flux de vidéos depuis internet (notamment Arte).

* [Tuto Ubuntu](http://doc.ubuntu-fr.org/youtube-dl)

* [Manuel Ubuntu](http://manpages.ubuntu.com/manpages/focal/en/man1/youtube-dl.1.html) (en)

### HexChat

Client IRC pour suivre l'actualité de ***#archlinux-fr, archlinux-aur, archlinux-br, archlinux-es, archlinux-pt, archlinux-ve, archlinux-women, archlinux-niewbie, archlinux-wiki***.

## Configurations matérielles

### Bluetooth
Trois paquets sont nécéssaires : [bluez](https://archlinux.org/packages/extra/x86_64/bluez/), [bluez-utils](https://archlinux.org/packages/extra/x86_64/bluez-utils/) et [blueman](https://archlinux.org/packages/community/x86_64/blueman/).
L'icône bluetooth apparaît dans la barre du menue et la conifgurtion se fait par la boîte de dialogue.
### Régler le pavé tactil
#### Installer le paquet libinput-gestures
Via AUR, installer le paquet [libinput-gestures](https://aur.archlinux.org/packages/libinput-gestures).
```
yay -S libinput-gestures
```
Pour la configuration, voir [ici](https://github.com/bulletmark/libinput-gestures).

Le pavé tactil à souvent tendance à être sensible y compris lors de la frappe sur le clavier. Le paramétrage du système (Cinnamon ou Gnome) peut être insuffisant. Plusieurs solutions...
<br>
#### Installer et utiliser dconf (utilitaire pour utiliser et paramétrer Gnome)
```
sudo pacman -S deconf-editor
```
taper "touchpad" dans la barre de rechreche et contrôler les paramères.
#### Utiliser Synaptics
Les wikis : [touchpad Synaptics](https://wiki.archlinux.org/title/Touchpad_Synaptics) (en [français](https://wiki.archlinux.fr/Touchpad_Synaptics)).

Attention, les réglages de dconf sont prioritaires sur ceux de Synaptic

## Configuration système

### Installer plusieurs noyaux linux

D'après la vidéo tuto de F. Beziès : [https://www.youtube.com/watch?v=LIYCeBDIy5w](https://www.youtube.com/watch?v=LIYCeBDIy5w)

Pour connaitre le noyaux linux qui est installé :

```
uname -a
```

On installe le noyaux voulu (ex: linux-lts :

```
$ sudo pacman -S linux-lts linux-lts-headers
```

Pour vérifier que les trois noyaux soient bien installés :

```
ls /boot
```

Pour intervenir dans le grub afin que les noyaux apparaissent dans le chargeur de démarrage :

```
sudo grub-mkconfig -o /boot/grub/grub.cfg
```

### Configurer le GRUB

#### Modifier l'entrée par défaut dans le grub

- [https://wiki.archlinux.fr/GRUB/Trucs_et_Astuces#Entr.C3.A9es_Multiples](https://wiki.archlinux.fr/GRUB/Trucs_et_Astuces#Entr.C3.A9es_Multiples)

- [https://doc.ubuntu-fr.org/tutoriel/grub2_parametrage_manuel#menu_par_defaut](https://doc.ubuntu-fr.org/tutoriel/grub2_parametrage_manuel#menu_par_defaut)

##### Mémorisation du dernier choix

GRUB peut se souvenir de la dernière entrée démarrée et l'utiliser comme entrée de démarrage par défaut pour la prochaine fois. Pour ce faire, éditez `/etc/default/grub` et modifiez la valeur de GRUB_DEFAULT:

```
GRUB_DEFAULT=saved
```

Ceci garantit que GRUB passe par défaut à l'entrée sauvegardée. Pour activer la sauvegarde de l'entrée sélectionnée, ajoutez la ligne suivante à `/etc/default/grub`:

```
GRUB_SAVEDEFAULT=true
```
##### Changer l'entrée par défaut du menu

Pour changer l'entrée par défaut du menu, éditer `/etc/default/grub` et modifier la valeur de `GRUB_DEFAULT`:

En utilisant les titres :

```
GRUB_DEFAULT='Advanced options for Arch Linux>Arch Linux, with Linux linux'
```

En utilisant les nombres :

```
GRUB_DEFAULT="1>2"
```

Grub identifie les entrées du menu généré par comptage depuis zero. Ce qui signifie 0 pour la première entrée qui est celle par défaut, 1 pour la deuxième et ainsi de suite. Les entrées du menu principal et des sous-menus sont séparées par un >.

L'exemple ci-dessus démarre la troisième entrée du menu principal : 'Advanced options for Arch Linux'.

Il faut ensuite recharger le grub :

```
sudo grub-mkconfig -o /boot/grub/grub.cfg
```
#### Afficher l'entrée Windows dans le menu du grub
```
GRUB_DISABLE_OS_PROBER=false
```

### Fin ###